pub enum MailboxDeliveryResult {
Success(usize),
Failure,
}Expand description
Represents the result of attempting to deliver a message to a mailbox.
Variants
Success(usize)
The message was successfully delivered to the specified number of mailboxes.
Failure
The message could not be delivered to any mailboxes.