pub enum UiNotification {
NewMessage(Message),
PeerConnected(PeerId),
PeerDisconnected(PeerId),
DeliveryStatusUpdate {
message_id: Uuid,
new_status: DeliveryStatus,
},
}Expand description
Represents a notification to be sent to the UI.
Variants
NewMessage(Message)
A new message has been received.
PeerConnected(PeerId)
A peer has connected.
PeerDisconnected(PeerId)
A peer has disconnected.
DeliveryStatusUpdate
The delivery status of a message has been updated.